==> gwoodworks-1.1.1-1.20.1-fabric-sources.jar: com/macuguita/woodworks/fabric/datagen/GWRecipeProvider.java <==
/*
 * Copyright (c) 2025 macuguita.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.macuguita.woodworks.fabric.datagen;

import java.util.function.Consumer;

import com.macuguita.woodworks.reg.GWObjects;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricRecipeProvider;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2444;
import net.minecraft.class_2447;
import net.minecraft.class_7800;

public class GWRecipeProvider extends FabricRecipeProvider {

	public GWRecipeProvider(FabricDataOutput output) {
		super(output);
	}

	@Override
	public void method_10419(Consumer<class_2444> consumer) {
		class_2447.method_10436(class_7800.field_40638, GWObjects.SECATEURS.get(), 1)
				.method_10439("#$")
				.method_10439(" #")
				.method_10434('#', class_1802.field_8675)
				.method_10434('$', class_1802.field_8868)
				.method_10429(method_32807(class_1802.field_8675), method_10426(class_1802.field_8675))
				.method_10429(method_32807(class_1802.field_8868), method_10426(class_1802.field_8868))
				.method_10431(consumer);

		GWObjects.STUMP_BLOCKS.stream().forEach(regEntry -> {
			createStumpRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_STUMP_BLOCKS.stream().forEach(regEntry -> {
			createStumpRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.CARVED_LOG_BLOCKS.stream().forEach(regEntry -> {
			createCarvedLogRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_CARVED_LOG_BLOCKS.stream().forEach(regEntry -> {
			createCarvedLogRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.BEAM_BLOCKS.stream().forEach(regEntry -> {
			createBeamRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_BEAM_BLOCKS.stream().forEach(regEntry -> {
			createBeamRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.HOLLOW_LOG_BLOCKS.stream().forEach(regEntry -> {
			createHollowLogRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_HOLLOW_LOG_BLOCKS.stream().forEach(regEntry -> {
			createHollowLogRecipe(consumer, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		createStumpRecipe(consumer, GWObjects.MUSHROOM_STUMP.get(), class_2246.field_10556);
		createCarvedLogRecipe(consumer, GWObjects.CARVED_MUSHROOM_STEM.get(), class_2246.field_10556);
		createBeamRecipe(consumer, GWObjects.MUSHROOM_BEAM.get(), class_2246.field_10556);
		createHollowLogRecipe(consumer, GWObjects.HOLLOW_MUSHROOM_STEM.get(), class_2246.field_10556);
	}

	private void createStumpRecipe(Consumer<class_2444> consumer, class_2248 stump, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, stump, 6)
				.method_10439("###")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(consumer);
	}

	private void createCarvedLogRecipe(Consumer<class_2444> consumer, class_2248 carvedLog, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, carvedLog, 6)
				.method_10439("#  ")
				.method_10439("#  ")
				.method_10439("###")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(consumer);
	}

	private void createBeamRecipe(Consumer<class_2444> consumer, class_2248 carvedLog, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, carvedLog, 12)
				.method_10439("#")
				.method_10439("#")
				.method_10439("#")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(consumer);
	}

	private void createHollowLogRecipe(Consumer<class_2444> consumer, class_2248 carvedLog, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, carvedLog, 12)
				.method_10439("# #")
				.method_10439("# #")
				.method_10439("# #")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(consumer);
	}
}

==> gwoodworks-1.1.1-1.21.1-fabric-sources.jar: com/macuguita/woodworks/fabric/datagen/GWRecipeProvider.java <==
/*
 * Copyright (c) 2025 macuguita.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.macuguita.woodworks.fabric.datagen;

import java.util.concurrent.CompletableFuture;

import com.macuguita.woodworks.reg.GWObjects;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricRecipeProvider;
import net.minecraft.class_1802;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2447;
import net.minecraft.class_7225;
import net.minecraft.class_7800;
import net.minecraft.class_8790;

public class GWRecipeProvider extends FabricRecipeProvider {

	public GWRecipeProvider(FabricDataOutput output, CompletableFuture<class_7225.class_7874> registriesFuture) {
		super(output, registriesFuture);
	}

	@Override
	public void method_10419(class_8790 recipeExporter) {
		class_2447.method_10436(class_7800.field_40638, GWObjects.SECATEURS.get(), 1)
				.method_10439("#$")
				.method_10439(" #")
				.method_10434('#', class_1802.field_8675)
				.method_10434('$', class_1802.field_8868)
				.method_10429(method_32807(class_1802.field_8675), method_10426(class_1802.field_8675))
				.method_10429(method_32807(class_1802.field_8868), method_10426(class_1802.field_8868))
				.method_10431(recipeExporter);

		GWObjects.STUMP_BLOCKS.stream().forEach(regEntry -> {
			createStumpRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_STUMP_BLOCKS.stream().forEach(regEntry -> {
			createStumpRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.CARVED_LOG_BLOCKS.stream().forEach(regEntry -> {
			createCarvedLogRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_CARVED_LOG_BLOCKS.stream().forEach(regEntry -> {
			createCarvedLogRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.BEAM_BLOCKS.stream().forEach(regEntry -> {
			createBeamRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_BEAM_BLOCKS.stream().forEach(regEntry -> {
			createBeamRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.HOLLOW_LOG_BLOCKS.stream().forEach(regEntry -> {
			createHollowLogRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		GWObjects.STRIPPED_HOLLOW_LOG_BLOCKS.stream().forEach(regEntry -> {
			createHollowLogRecipe(recipeExporter, regEntry.get(), GWObjects.WOOD_ASSOCIATIONS.get(regEntry.get()));
		});
		createStumpRecipe(recipeExporter, GWObjects.MUSHROOM_STUMP.get(), class_2246.field_10556);
		createCarvedLogRecipe(recipeExporter, GWObjects.CARVED_MUSHROOM_STEM.get(), class_2246.field_10556);
		createBeamRecipe(recipeExporter, GWObjects.MUSHROOM_BEAM.get(), class_2246.field_10556);
		createHollowLogRecipe(recipeExporter, GWObjects.HOLLOW_MUSHROOM_STEM.get(), class_2246.field_10556);
	}

	private void createStumpRecipe(class_8790 exporter, class_2248 stump, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, stump, 6)
				.method_10439("###")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(exporter);
	}

	private void createCarvedLogRecipe(class_8790 exporter, class_2248 carvedLog, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, carvedLog, 6)
				.method_10439("#  ")
				.method_10439("#  ")
				.method_10439("###")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(exporter);
	}

	private void createBeamRecipe(class_8790 exporter, class_2248 carvedLog, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, carvedLog, 12)
				.method_10439("#")
				.method_10439("#")
				.method_10439("#")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(exporter);
	}

	private void createHollowLogRecipe(class_8790 exporter, class_2248 carvedLog, class_2248 log) {
		class_2447.method_10436(class_7800.field_40635, carvedLog, 12)
				.method_10439("# #")
				.method_10439("# #")
				.method_10439("# #")
				.method_10434('#', log)
				.method_10429(method_32807(log), method_10426(log))
				.method_10431(exporter);
	}
}
